@@ -1,5 +1,5 @@
 /* version.c --- Version handling.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,7 +23,7 @@
 
 #include "stringprep.h"
 
-#include <strverscmp.h>
+#include <string.h> /* for strverscmp */
 
 /**
  * stringprep_check_version - check for library version
